BreathingAnimation class

呼吸动画配置类 包含呼吸灯效果的所有相关配置参数

Constructors

BreathingAnimation({bool enabled = true, Color color = Colors.white, Duration duration = const Duration(seconds: 2), double opacityMin = 0.2, double opacityMax = 0.9, double gap = 2.0, double strokeWidth = 3.0})
创建呼吸动画配置
const
BreathingAnimation.disabled()
创建禁用呼吸动画的配置
const

Properties

color Color
呼吸动画颜色
final
duration Duration
呼吸动画持续时间
final
enabled bool
是否启用呼吸动画
final
gap double
呼吸动画与顶点的间距
final
hashCode int
The hash code for this object.
no setterinherited
opacityMax double
呼吸动画最大透明度
final
opacityMin double
呼吸动画最小透明度
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double
呼吸动画线条宽度
final

Methods

copyWith({bool? enabled, Color? color, Duration? duration, double? opacityMin, double? opacityMax, double? gap, double? strokeWidth}) BreathingAnimation
复制并修改配置
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited