FineAdjustmentConfiguration class

精调模式配置

Constructors

FineAdjustmentConfiguration({Duration longPressDuration = const Duration(milliseconds: 800), double sensitivity = 0.2, String hintText = 'Fine adjustment mode: Drag slightly for precise adjustments', TextStyle hintTextStyle = const TextStyle(color: Colors.white, fontSize: 12, fontWeight: FontWeight.w500), Color hintBackgroundColor = const Color(0x88000000), double hintMargin = 20.0, FineAdjustmentMode mode = FineAdjustmentMode.both, VirtualDPadConfiguration dpadConfig = const VirtualDPadConfiguration()})
const

Properties

dpadConfig VirtualDPadConfiguration
虚拟方向键配置
final
hashCode int
The hash code for this object.
no setterinherited
hintBackgroundColor Color
精调模式背景色
final
hintMargin double
精调模式提示距离屏幕边缘的距离
final
hintText String
精调模式提示文本
final
hintTextStyle TextStyle
精调模式提示文本样式
final
longPressDuration Duration
长按触发精调模式的时间(毫秒)
final
mode FineAdjustmentMode
精调模式类型
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensitivity double
精调模式下的灵敏度系数(0.1表示正常速度的1/10)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited