MagnifierPositionMode enum

放大镜位置模式

Inheritance
Available extensions

Values

center → const MagnifierPositionMode

放大镜圆心在手势点击位置(默认模式)

corner → const MagnifierPositionMode

放大镜固定在四个角之一

edge → const MagnifierPositionMode

放大镜边缘在手势点击位置,有偏移避免遮挡

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MagnifierPositionMode>
A constant List of the values in this enum, in order of their declaration.