QuadAnnotatorController class

QuadAnnotator的控制器,用于控制QuadAnnotatorBox的行为

Constructors

QuadAnnotatorController()
构造函数

Properties

hashCode int
The hash code for this object.
no setterinherited
isDragging bool
获取当前拖拽状态
no setter
onDragging bool Function()?
拖动状态的回调函数
getter/setter pair
onImageVertices List<Point<double>>? Function()?
获取图片顶点坐标的回调函数
getter/setter pair
onReset ↔ void Function()?
重置顶点的回调函数
getter/setter pair
onStartTutorial ↔ void Function()?
启动引导的回调函数
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vertices List<Point<double>>?
获取当前顶点坐标(图片坐标系) 返回转换为图片真实坐标的顶点列表,如果当前没有矩形则返回null
no setter

Methods

dispose() → void
释放资源 在不再使用controller时调用,清理回调函数
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
重置顶点到默认位置 将矩形重置为组件的默认大小和位置
startTutorial() → void
启动引导 手动启动引导流程,从第一步开始
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited