QuadImageInfo class
图片信息类,包含图片的真实尺寸和显示尺寸
Constructors
- QuadImageInfo({required Size realSize, required Size displaySize, required Offset offset})
-
const
Properties
- displaySize → Size
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- offset → Offset
-
final
- realSize → Size
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited