TutorialStep enum
引导步骤枚举
Values
- none → const TutorialStep
-
无引导
- dragVertex → const TutorialStep
-
步骤1:拖拽顶点引导
- longPressVertex → const TutorialStep
-
步骤2:长按进入精调模式引导
- doubleTapVertex → const TutorialStep
-
步骤3:双击顶点引导
- useDPad → const TutorialStep
-
步骤4:使用方向键引导
- switchVertex → const TutorialStep
-
步骤5:切换顶点引导
- dragDPadPanel → const TutorialStep
-
步骤6:拖拽方向键面板引导
- completed → const TutorialStep
-
引导完成
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TutorialStep> - A constant List of the values in this enum, in order of their declaration.