VirtualDPadConfiguration class

虚拟方向键配置

Constructors

VirtualDPadConfiguration({Color backgroundColor = const Color(0x4D000000), Color highlightColor = const Color(0x4DFFFFFF), Color borderColor = Colors.white, double borderWidth = 1.0, Alignment position = Alignment.bottomLeft, double margin = 20.0, double size = 40.0, Color iconColor = Colors.white, double iconSize = 8, double stepSize = 1.0, double centerButtonSize = 50.0, Color centerButtonColor = const Color(0x4D000000), TextStyle centerButtonTextStyle = const TextStyle(color: Colors.white, fontSize: 20, fontWeight: FontWeight.w500), bool enableHapticFeedback = true})
构造函数
const

Properties

backgroundColor Color
方向键背景色
final
borderColor Color
虚拟摇杆边框色
final
borderWidth double
虚拟摇杆边框宽度
final
centerButtonColor Color
中心按钮背景色
final
centerButtonSize double
中心按钮大小
final
centerButtonTextStyle TextStyle
中心按钮文字样式
final
enableHapticFeedback bool
是否启用触觉反馈
final
hashCode int
The hash code for this object.
no setterinherited
highlightColor Color
方向键高亮背景色
final
iconColor Color
方向键图标色
final
iconSize double
方向键图标大小
final
margin double
虚拟按键外边距
final
position Alignment
方向键初始位置(相对于屏幕)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
方向键大小
final
stepSize double
每次点击移动的像素数
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited